@@ -18,6 +18,7 @@ import datetime
 import dateutil.parser
 from numbers import Number
 
+import utils
 from .utils import get_logger, to_datetime, to_date
 
 log = get_logger(__name__)
@@ -201,7 +202,10 @@ class String(Property):
         return type_system.database.to_string(value)
 
     def to_python(self,type_system,value):
-        return type_system.python.to_string(value)    
+        return type_system.python.to_string(value)
+
+    def _coerce(self, value):
+        return utils.u(value)
 
 class Integer(Property):    
     """
